@@ -1,4 +1,4 @@
-// C++/WinRT v2.0.240111.5
+// C++/WinRT v2.0.240405.15
 
 // SPDX-License-Identifier: MIT OR Apache-2.0
 // SPDX-FileCopyrightText: Copyright (c) Microsoft Corporation
@@ -29,6 +29,13 @@ WINRT_EXPORT namespace winrt::Windows::Media::Audio
         AudioDeviceOutputNode(std::nullptr_t) noexcept {}
         AudioDeviceOutputNode(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Media::Audio::IAudioDeviceOutputNode(ptr, take_ownership_from_abi) {}
     };
+    struct WINRT_IMPL_EMPTY_BASES AudioEffectsPackConfiguration : winrt::Windows::Media::Audio::IAudioEffectsPackConfiguration
+    {
+        AudioEffectsPackConfiguration(std::nullptr_t) noexcept {}
+        AudioEffectsPackConfiguration(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Media::Audio::IAudioEffectsPackConfiguration(ptr, take_ownership_from_abi) {}
+        static auto GetForDeviceId(param::hstring const& effectsPackId, param::hstring const& deviceId);
+        static auto IsDeviceIdSupported(param::hstring const& effectsPackId, param::hstring const& deviceId);
+    };
     struct WINRT_IMPL_EMPTY_BASES AudioFileInputNode : winrt::Windows::Media::Audio::IAudioFileInputNode,
         impl::require<AudioFileInputNode, winrt::Windows::Media::Audio::IAudioInputNode2>
     {
